@@ -8,7 +8,7 @@ from drf_spectacular.utils import OpenApiExample, extend_schema_field, extend_sc
 from rest_framework import serializers
 
 from db.base.models import TRANSMITTER_STATUS, Artifact, DemodData, LatestTleSet, Mode, \
-    Satellite, Telemetry, Transmitter
+    Satellite, SatelliteEntry, Telemetry, Transmitter, TransmitterEntry
 
 
 @extend_schema_serializer(
@@ -41,6 +41,16 @@ class SatTelemetrySerializer(serializers.ModelSerializer):
         fields = ['decoder']
 
 
+class SatelliteEntrySerializer(serializers.ModelSerializer):
+    """SatNOGS DB SatelliteEntry API Serializer"""
+    class Meta:
+        model = SatelliteEntry
+        fields = (
+            'satellite_identifier', 'norad_cat_id', 'name', 'names', 'status', 'citation',
+            'created_by'
+        )
+
+
 @extend_schema_serializer(
     examples=[
         OpenApiExample(
@@ -70,26 +80,127 @@ class SatTelemetrySerializer(serializers.ModelSerializer):
 class SatelliteSerializer(serializers.ModelSerializer):
     """SatNOGS DB Satellite API Serializer"""
 
-    telemetries = SatTelemetrySerializer(many=True, read_only=True)
+    sat_id = serializers.SerializerMethodField()
+    norad_cat_id = serializers.SerializerMethodField()
+    name = serializers.SerializerMethodField()
+    names = serializers.SerializerMethodField()
+    image = serializers.SerializerMethodField()
+    status = serializers.SerializerMethodField()
+    decayed = serializers.SerializerMethodField()
+    launched = serializers.SerializerMethodField()
+    deployed = serializers.SerializerMethodField()
+    website = serializers.SerializerMethodField()
+    operator = serializers.SerializerMethodField()
     countries = serializers.SerializerMethodField()
+    telemetries = serializers.SerializerMethodField()
+    updated = serializers.SerializerMethodField()
+    citation = serializers.SerializerMethodField()
+    associated_satellites = serializers.SerializerMethodField()
     operator = serializers.SerializerMethodField()
 
     class Meta:
         model = Satellite
         fields = (
-            'norad_cat_id', 'name', 'names', 'image', 'status', 'decayed', 'launched', 'deployed',
-            'website', 'operator', 'countries', 'telemetries'
+            'sat_id', 'norad_cat_id', 'name', 'names', 'image', 'status', 'decayed', 'launched',
+            'deployed', 'website', 'operator', 'countries', 'telemetries', 'updated', 'citation',
+            'associated_satellites'
         )
 
+    @extend_schema_field(OpenApiTypes.STR)
+    def get_sat_id(self, obj):
+        """Returns Satellite sat_id"""
+        return obj.satellite_identifier.sat_id
+
+    @extend_schema_field(OpenApiTypes.INT64)
+    def get_norad_cat_id(self, obj):
+        """Returns Satellite norad_cat_id"""
+        return obj.satellite_entry.norad_cat_id
+
+    @extend_schema_field(OpenApiTypes.STR)
+    def get_name(self, obj):
+        """Returns Satellite name"""
+        return obj.satellite_entry.name
+
+    @extend_schema_field(OpenApiTypes.STR)
+    def get_names(self, obj):
+        """Returns Satellite alternative names"""
+        return obj.satellite_entry.names
+
+    @extend_schema_field(OpenApiTypes.URI)
+    def get_image(self, obj):
+        """Returns Satellite image URI"""
+        return str(obj.satellite_entry.image)
+
+    @extend_schema_field(OpenApiTypes.STR)
+    def get_status(self, obj):
+        """Returns Satellite status text"""
+        return obj.satellite_entry.status
+
+    @extend_schema_field(OpenApiTypes.DATETIME)
+    def get_decayed(self, obj):
+        """Returns Satellite decayed datetime"""
+        return obj.satellite_entry.decayed
+
+    @extend_schema_field(OpenApiTypes.DATETIME)
+    def get_launched(self, obj):
+        """Returns Satellite launched datetime"""
+        return obj.satellite_entry.launched
+
+    @extend_schema_field(OpenApiTypes.DATETIME)
+    def get_deployed(self, obj):
+        """Returns Satellite deployed datetime"""
+        return obj.satellite_entry.deployed
+
+    @extend_schema_field(OpenApiTypes.URI)
+    def get_website(self, obj):
+        """Returns Satellite website"""
+        return obj.satellite_entry.website
+
     @extend_schema_field(OpenApiTypes.STR)
     def get_operator(self, obj):
         """Returns operator text"""
-        return str(obj.operator)
+        return str(obj.satellite_entry.operator)
 
     @extend_schema_field(OpenApiTypes.STR)
     def get_countries(self, obj):
         """Returns countires"""
-        return ','.join(map(str, obj.countries))
+        return obj.satellite_entry.countries_str
+
+    @extend_schema_field(OpenApiTypes.OBJECT)
+    def get_telemetries(self, obj):
+        """Returns telemetries"""
+        telemetries = SatTelemetrySerializer(obj.telemetries, many=True, read_only=True)
+        return telemetries.data
+
+    @extend_schema_field(OpenApiTypes.DATETIME)
+    def get_updated(self, obj):
+        """Returns Satellite decayed datetime"""
+        return obj.satellite_entry.reviewed
+
+    @extend_schema_field(OpenApiTypes.STR)
+    def get_citation(self, obj):
+        """Returns Satellite decayed datetime"""
+        return obj.satellite_entry.citation
+
+    @extend_schema_field(OpenApiTypes.OBJECT)
+    def get_associated_satellites(self, obj):
+        """Returns Satellite decayed datetime"""
+        return [
+            merged_satellite.satellite_identifier.sat_id
+            for merged_satellite in obj.associated_with.all()
+        ]
+
+
+class TransmitterEntrySerializer(serializers.ModelSerializer):
+    """SatNOGS DB TransmitterEntry API Serializer"""
+    class Meta:
+        model = TransmitterEntry
+        fields = (
+            'uuid', 'description', 'status', 'type', 'uplink_low', 'uplink_high', 'uplink_drift',
+            'downlink_low', 'downlink_high', 'downlink_drift', 'downlink_mode', 'uplink_mode',
+            'invert', 'baud', 'satellite', 'citation', 'service', 'iaru_coordination',
+            'iaru_coordination_url', 'itu_coordination', 'created_by'
+        )
 
 
 @extend_schema_serializer(
@@ -118,8 +229,9 @@ class SatelliteSerializer(serializers.ModelSerializer):
                 'updated': '2020-09-03T13:14:41.552071Z',
                 'citation': 'https://www.ariss.org/press-releases/september-2-2020',
                 'service': 'Amateur',
-                'coordination': '',
-                'coordination_url': ''
+                'iaru_coordination': '',
+                'iaru_coordination_url': '',
+                'itu_coordination': ''
             },
             response_only=True,  # signal that example only applies to responses
         ),
@@ -127,6 +239,7 @@ class SatelliteSerializer(serializers.ModelSerializer):
 )
 class TransmitterSerializer(serializers.ModelSerializer):
     """SatNOGS DB Transmitter API Serializer"""
+    sat_id = serializers.SerializerMethodField()
     norad_cat_id = serializers.SerializerMethodField()
     mode = serializers.SerializerMethodField()
     mode_id = serializers.SerializerMethodField()
@@ -139,8 +252,8 @@ class TransmitterSerializer(serializers.ModelSerializer):
         fields = (
             'uuid', 'description', 'alive', 'type', 'uplink_low', 'uplink_high', 'uplink_drift',
             'downlink_low', 'downlink_high', 'downlink_drift', 'mode', 'mode_id', 'uplink_mode',
-            'invert', 'baud', 'norad_cat_id', 'status', 'updated', 'citation', 'service',
-            'coordination', 'coordination_url'
+            'invert', 'baud', 'sat_id', 'norad_cat_id', 'status', 'updated', 'citation', 'service',
+            'iaru_coordination', 'iaru_coordination_url', 'itu_coordination'
         )
 
     # Keeping alive field for compatibility issues
@@ -177,7 +290,15 @@ class TransmitterSerializer(serializers.ModelSerializer):
     def get_norad_cat_id(self, obj):
         """Returns Satellite NORAD ID"""
         try:
-            return obj.satellite.norad_cat_id
+            return obj.satellite.satellite_entry.norad_cat_id
+        except AttributeError:
+            return None
+
+    @extend_schema_field(OpenApiTypes.STR)
+    def get_sat_id(self, obj):
+        """Returns Satellite NORAD ID"""
+        try:
+            return obj.satellite.satellite_identifier.sat_id
         except AttributeError:
             return None
 
@@ -202,6 +323,7 @@ class TransmitterSerializer(serializers.ModelSerializer):
 class LatestTleSetSerializer(serializers.ModelSerializer):
     """SatNOGS DB LatestTleSet API Serializer"""
 
+    sat_id = serializers.SerializerMethodField()
     norad_cat_id = serializers.SerializerMethodField()
     tle0 = serializers.SerializerMethodField()
     tle1 = serializers.SerializerMethodField()
@@ -211,12 +333,17 @@ class LatestTleSetSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = LatestTleSet
-        fields = ('tle0', 'tle1', 'tle2', 'tle_source', 'norad_cat_id', 'updated')
+        fields = ('tle0', 'tle1', 'tle2', 'tle_source', 'sat_id', 'norad_cat_id', 'updated')
+
+    @extend_schema_field(OpenApiTypes.STR)
+    def get_sat_id(self, obj):
+        """Returns Satellite Satellite Identifier"""
+        return obj.satellite.satellite_identifier.sat_id
 
     @extend_schema_field(OpenApiTypes.INT64)
     def get_norad_cat_id(self, obj):
         """Returns Satellite NORAD ID"""
-        return obj.satellite.norad_cat_id
+        return obj.satellite.satellite_entry.norad_cat_id
 
     @extend_schema_field(OpenApiTypes.STR)
     def get_tle0(self, obj):
@@ -273,23 +400,33 @@ class LatestTleSetSerializer(serializers.ModelSerializer):
 )
 class TelemetrySerializer(serializers.ModelSerializer):
     """SatNOGS DB Telemetry API Serializer"""
+    sat_id = serializers.SerializerMethodField()
     norad_cat_id = serializers.SerializerMethodField()
     transmitter = serializers.SerializerMethodField()
     schema = serializers.SerializerMethodField()
     decoded = serializers.SerializerMethodField()
     frame = serializers.SerializerMethodField()
+    associated_satellites = serializers.SerializerMethodField()
 
     class Meta:
         model = DemodData
         fields = (
-            'norad_cat_id', 'transmitter', 'app_source', 'schema', 'decoded', 'frame', 'observer',
-            'timestamp', 'version', 'observation_id', 'station_id'
+            'sat_id', 'norad_cat_id', 'transmitter', 'app_source', 'schema', 'decoded', 'frame',
+            'observer', 'timestamp', 'version', 'observation_id', 'station_id',
+            'associated_satellites'
         )
 
+    @extend_schema_field(OpenApiTypes.STR)
+    def get_sat_id(self, obj):
+        """Returns Satellite Identifier"""
+        if obj.satellite.associated_satellite:
+            return obj.satellite.associated_satellite.satellite_identifier.sat_id
+        return obj.satellite.satellite_identifier.sat_id
+
     @extend_schema_field(OpenApiTypes.INT64)
     def get_norad_cat_id(self, obj):
-        """Returns Satellite NORAD ID for this Transmitter"""
-        return obj.satellite.norad_cat_id
+        """Returns Satellite NORAD ID"""
+        return obj.satellite.satellite_entry.norad_cat_id
 
     @extend_schema_field(OpenApiTypes.UUID)
     def get_transmitter(self, obj):
@@ -318,6 +455,17 @@ class TelemetrySerializer(serializers.ModelSerializer):
         """Returns the payload frame"""
         return obj.display_frame()
 
+    @extend_schema_field(OpenApiTypes.OBJECT)
+    def get_associated_satellites(self, obj):
+        """Returns Satellite decayed datetime"""
+        satellite = obj.satellite
+        if satellite.associated_satellite:
+            satellite = satellite.associated_satellite
+        return [
+            merged_satellite.satellite_identifier.sat_id
+            for merged_satellite in satellite.associated_with.all()
+        ]
+
     # @extend_schema_field(OpenApiTypes.STR)
     # def get_version(self, obj):
     #     """Returns the payload version"""
