@@ -1,6 +1,5 @@
 """SatNOGS DB django rest framework API url routings"""
-from django.conf.urls import include
-from django.urls import path
+from django.urls import include, path
 from rest_framework import routers
 
 from db.api import views
