@@ -320,8 +320,6 @@ class TransmitterViewSet(  # pylint: disable=R0901
             transmitter_data['status'] = transmitter['status']
             transmitter_data['citation'] = transmitter['citation']
             transmitter_data['service'] = transmitter['service']
-            transmitter_data['coordination'] = ''
-            transmitter_data['coordination_url'] = ''
             transmitter_data['created_by'] = request.user.pk
 
             try:
