@@ -30,11 +30,8 @@ SERVICE_TYPE = [
     'Maritime', 'Meteorological', 'Mobile', 'Radiolocation', 'Radionavigational',
     'Space Operation', 'Space Research', 'Standard Frequency and Time Signal', 'Unknown'
 ]
-COORDINATION_STATUS = [
-    'ITU Requested', 'ITU Rejected', 'ITU Coordinated', 'IARU Requested', 'IARU Declined',
-    'IARU Coordinated', 'Uncoordinated'
-]
-BAD_COORDINATIONS = ['ITU Rejected', 'IARU Declined', 'Uncoordinated']  # 'violations'
+IARU_COORDINATION_STATUS = ['IARU Coordinated', 'IARU Declined', 'IARU Uncoordinated', 'N/A']
+BAD_COORDINATIONS = ['IARU Declined', 'IARU Uncoordinated']  # 'violations'
 URL_REGEX = r"(?:http(s)?:\/\/)?[\w.-]+(?:\.[\w\.-]+)+[\w\-\._~:/?#[\]@!\$&'\(\)\*\+,;=.]+$"
 MIN_FREQ = 0
 MAX_FREQ = 40000000000
@@ -105,6 +102,11 @@ def generate_sat_id():
     )
 
 
+def get_default_itu_coordination_field():
+    """Generate default value for itu_coordination field of TransmitterEntry model"""
+    return {'urls': []}
+
+
 class SatelliteIdentifier(models.Model):
     """Model for Satellite Identifier."""
     sat_id = models.CharField(
@@ -489,18 +491,18 @@ class TransmitterEntry(models.Model):
         default='Unknown',
         help_text='The published usage category for this transmitter'
     )
-    coordination = models.CharField(
-        choices=list(zip(COORDINATION_STATUS, COORDINATION_STATUS)),
+    iaru_coordination = models.CharField(
+        choices=list(zip(IARU_COORDINATION_STATUS, IARU_COORDINATION_STATUS)),
         max_length=20,
-        blank=True,
-        default='',
-        help_text='Frequency coordination status for this transmitter'
+        default='N/A',
+        help_text='IARU frequency coordination status for this transmitter'
     )
-    coordination_url = models.URLField(
+    iaru_coordination_url = models.URLField(
         blank=True,
         help_text='URL for more details on this frequency coordination',
         validators=[URLValidator(schemes=['http', 'https'], regex=URL_REGEX)]
     )
+    itu_coordination = models.JSONField(default=get_default_itu_coordination_field)
     reviewer = models.ForeignKey(
         get_user_model(),
         related_name='reviewed_transmitters',
@@ -528,7 +530,7 @@ class TransmitterEntry(models.Model):
 
         :returns: bool
         """
-        if self.coordination in BAD_COORDINATIONS:
+        if self.iaru_coordination in BAD_COORDINATIONS:
             return True
         return False
 
