@@ -12,8 +12,8 @@ from django.utils.timezone import now
 from factory import fuzzy
 from pytest_django.asserts import assertContains  # pylint: disable=E0611
 
-from db.base.models import DATA_SOURCES, DemodData, Mode, Satellite, SatelliteEntry, \
-    SatelliteIdentifier, Telemetry, Transmitter, TransmitterSuggestion
+from db.base.models import DATA_SOURCES, IARU_COORDINATION_STATUS, DemodData, Mode, Satellite, \
+    SatelliteEntry, SatelliteIdentifier, Telemetry, Transmitter, TransmitterSuggestion
 
 DATA_SOURCE_IDS = [c[0] for c in DATA_SOURCES]
 
@@ -111,9 +111,7 @@ class TransmitterSuggestionFactory(factory.django.DjangoModelFactory):
     service = fuzzy.FuzzyChoice(
         choices=['Amateur', 'Broadcasting', 'Earth Exploration', 'Fixed', 'Inter-satellite']
     )
-    coordination = fuzzy.FuzzyChoice(
-        choices=['', 'IARU Requested', 'IARU Declined', 'IARU Coordinated', 'Uncoordinated']
-    )
+    iaru_coordination = fuzzy.FuzzyChoice(choices=IARU_COORDINATION_STATUS)
 
     class Meta:
         model = TransmitterSuggestion
