@@ -417,7 +417,7 @@ CSP_SCRIPT_SRC = config(
     'https://*.google-analytics.com,'
     'https://kit-free.fontawesome.com,'
     'https://kit.fontawesome.com,'
-    "'sha256-wMIRCqWVu9YgOwizZzrYvTWAiAn0Y8PQTRdiHy2BNRk=',"  # transmitter_modal.js
+    "'sha256-hNUUO5rlLTL2RGoi1tx0HAeOoB/Zc30JmlfQDwIq358=',"  # transmitter_modal.js
 )
 CSP_IMG_SRC = config(
     'CSP_IMG_SRC',
