@@ -24,20 +24,24 @@ $(document).ready(function() {
     $('.alert').each(function() {
         var alerticon = 'fas fa-question';
         var alerttitle = 'Unknown';
+        var alertclass = 'alert-info';
         if ($(this).data('alertclass') == 'alert-success') {
             alerticon = 'far fa-thumbs-up';
             alerttitle = 'Success';
+            alertclass = 'alert-success';
         }
         if ($(this).data('alertclass') == 'alert-error') {
             alerticon = 'fas fa-ban';
             alerttitle = 'Error';
+            alertclass = 'alert-danger';
         }
         if ($(this).data('alertclass') == 'alert-warning') {
             alerticon = 'fas fa-exclamation';
             alerttitle = 'Alert';
+            alertclass = 'alert-warning';
         }
         $(document).Toasts('create', {
-            class: $(this).data('alertclass'),
+            class: alertclass,
             title: alerttitle,
             autohide: true,
             delay: 6000,
